==> elki_0.6.0.orig.tar.bz2: elki-0.6.0/src/de/lmu/ifi/dbs/elki/data/projection/Projection.java <==
package de.lmu.ifi.dbs.elki.data.projection;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2013
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import de.lmu.ifi.dbs.elki.data.type.SimpleTypeInformation;
import de.lmu.ifi.dbs.elki.data.type.TypeInformation;
import de.lmu.ifi.dbs.elki.utilities.optionhandling.Parameterizable;

/**
 * Projection interface.
 * 
 * @author Erich Schubert
 * 
 * @param <IN> Input data type
 * @param <OUT> Output data type
 */
public interface Projection<IN, OUT> extends Parameterizable {
  /**
   * Initialize
   * 
   * @param in Data type to use for projecting.
   */
  public void initialize(SimpleTypeInformation<IN> in);

  /**
   * Project a single instance.
   * 
   * @param data Data to project
   * @return Projected data
   */
  public OUT project(IN data);

  /**
   * Input type information.
   * 
   * @return Type restriction
   */
  public TypeInformation getInputDataTypeInformation();

  /**
   * Output type restriction
   * 
   * @return Output type
   */
  public SimpleTypeInformation<OUT> getOutputDataTypeInformation();
}

==> elki_0.6.5~20141030.orig.tar.bz2: elki-0.6.5~20141030/src/de/lmu/ifi/dbs/elki/data/projection/Projection.java <==
package de.lmu.ifi.dbs.elki.data.projection;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2014
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import de.lmu.ifi.dbs.elki.data.type.SimpleTypeInformation;
import de.lmu.ifi.dbs.elki.data.type.TypeInformation;

/**
 * Projection interface.
 * 
 * @author Erich Schubert
 * 
 * @param <IN> Input data type
 * @param <OUT> Output data type
 */
public interface Projection<IN, OUT> {
  /**
   * Initialize
   * 
   * @param in Data type to use for projecting.
   */
  public void initialize(SimpleTypeInformation<IN> in);

  /**
   * Project a single instance.
   * 
   * @param data Data to project
   * @return Projected data
   */
  public OUT project(IN data);

  /**
   * Input type information.
   * 
   * @return Type restriction
   */
  public TypeInformation getInputDataTypeInformation();

  /**
   * Output type restriction
   * 
   * @return Output type
   */
  public SimpleTypeInformation<OUT> getOutputDataTypeInformation();
}
